# See https://git-scm.com/docs/githooks for more information
all_hooks = [
    # ('git-hook-name', 'modulename')
    ('post-rewrite', 'postrewrite'),
]
